@@ -20,8 +20,6 @@ from repository import *
 
 ### externalator internal constants
 
-svn_property = 'externalator:bundle'
-description_file = 'description.txt'
 svn_props = {'svn': 'svn:externals',
              'cvs': 'externalator:cvs',
              'tgz': 'externalator:tgz'}
@@ -165,10 +163,9 @@ class ExternalatorCommand(object, OptionParser):
         for i in self.arguments:
             if 'bundle' in i['type']:
                 pass
-            elif i['type'] == 'externals':
-                string.append('')
-                string.append('format of the externals string is:')
-                if i['settable']:                 
+            elif i['type'] == 'externals' and i['settable']:
+                    string.append('')
+                    string.append('format of the externals string is:')
                     string.append('SVN: externalname=r1234:http://repository.net/svn/product/package')
                     string.append('\t[revision number optional, or can be rNone to unset]')
                     string.append('CVS: externalname=product/package [please remember to use --cvs=CVSROOT')
@@ -425,23 +422,16 @@ class ExternalatorCommand(object, OptionParser):
 
     ### functions central to bundles
     
-    def is_bundle(self, repo, strict=None):
-        """ returns whether the repo is a bundle or not """    
-        
-        if strict is None:
-            strict = self.options['strict']
-
-        svn = SVN(repo)
-        
-        property = svn.readlines("propget", "externalator:bundle", repo)
-        if property:
+    def is_bundle(self, repo):
+        """ returns whether the repo is a bundle or not """
+        # XXX now there is now bundle checking!
+        # XXX this should always be true for a legitimate svn uri
+        try:
+            svn = SVN(repo)
             return True
-
-        if strict:
+        except Repository.RepositoryError:
             return False
-        else:
-            return True
-        return False
+        
 
     def check_bundle(self, bundle):
         """ 
@@ -451,7 +441,7 @@ class ExternalatorCommand(object, OptionParser):
         """
 
         # is the bundle a fully qualified svn uri?
-        if is_svn_uri(bundle) and self.is_bundle(bundle):
+        if is_svn_uri(bundle):
             return {'name': bundle,
                     'directory': None,
                     'location': bundle}
@@ -468,7 +458,7 @@ class ExternalatorCommand(object, OptionParser):
         svn = SVN(repo)
 
         return [ i.rstrip('/') for i in bundles 
-                 if self.is_bundle(svn.join(i), self.options['strict']) ] 
+                 if self.is_bundle(svn.join(i)) ] 
         
     ### functions for checking out temporary copies of repositories
 
@@ -912,55 +902,6 @@ class HelpCommand(ExternalatorCommand):
         return self.output()
                 
 
-class ImportCommand(ExternalatorCommand):
-    """ create a bundle from an svn repository directory """
-
-    def __init__(self):
-        ExternalatorCommand.__init__(self)
-        self.name = 'import'
-        self.add_path('repository location', optional=False)
-
-    def parse_args(self, *args):
-        if len(args) > 1:
-            self.error("Too many arguments to %s" % self.name)
-
-        if len(args):
-            self.repo = args[0]
-        else:
-            self.repo = '.'
-
-        self.options['repository'] = self.repo
-
-        self.check_repository()
-
-    def __call__(self):
-        svn = SVN(self.repo)
-        if not svn.is_repository():
-            self.error("%s is not an svn repository.  Please `svn import` it first" % self.repo)
-
-        if self.is_bundle(self.repo):
-            self.error("%s is already a bundle" % self.repo.rstrip('/'))
-
-        # add an svn tag for externalator:bundle
-        svn('propset', svn_property, 'True', self.repo)
-
-        # adds a description file if none exists
-        filename = os.path.join(self.repo, description_file)
-        if not os.path.exists(filename):
-            f = file(filename, 'w')
-            print >> f, '[ Bundle Description: ]'
-            if self.options['message']:
-                print >> f, self.options['message']
-                f.close()
-            else:
-                f.close()
-                self.edit(filename)
-
-        svn('add', filename)        
-        svn('commit', self.repo, '-m', 'tagging as an externalator bundle')
-        
-        return self.output()
-
 class ListCommand(ExternalatorCommand):
     """ lists bundles in a repository """
     
@@ -1006,7 +947,7 @@ class ListCommand(ExternalatorCommand):
         if not self.repolist:
             self.build_repo_list(repo)
 
-        if self.is_bundle(repo, self.options['strict']):
+        if self.is_bundle(repo):
             bundlelist.append(repo)
 
         # only consider directories
@@ -1019,7 +960,7 @@ class ListCommand(ExternalatorCommand):
     def list_bundles(self, repo):
         svn = SVN(repo)
         bundlelist = []
-        if self.is_bundle(repo, self.options['strict']):
+        if self.is_bundle(repo):
             bundlelist.append(repo)
             # should i return here?
             
@@ -1179,7 +1120,7 @@ class GetCommand(ExternalatorCommand):
             
 
         # get bundles and externals
-        if (self.is_bundle(args[0], self.options['strict'])):
+        if (self.is_bundle(args[0])):
             self.bundle_list = self.parse_bundles(*args)
         else:
             if not length:
@@ -1211,10 +1152,11 @@ class GetCommand(ExternalatorCommand):
         self.get_externals(m)
 
         found = [ False for item in self.externals ]
-        
+
+        retval = StringIO.StringIO()
         # display the externals
         for i in self.bundle_list:
-            print i['name']
+            print >> retval, i['name']
             for j in m:
                 ext = self.extdict[i['name']][j]
 
@@ -1247,21 +1189,21 @@ class GetCommand(ExternalatorCommand):
 
                 # display the table
                 if len(table) > min_table_size:
-                    print "%s externals:" % j
+                    print >> retval, "%s externals:" % j
                     for row in print_table(table):
-                        print row
-                    print ""
+                        print >> retval, row
+                    print >> retval, ""
                 else:
                     if not self.externals:
-                        print 'No %s externals' % j
+                        print >> retval, 'No %s externals' % j
 
             # display the externals that aren't found
             if self.externals:
                 for index in range(len(self.externals)):
                     if not found[index]:
-                        print 'No external "%s" found in %s bundle' % ( self.externals[index], i['name'] )
+                        print >> retval, 'No external "%s" found in %s bundle' % ( self.externals[index], i['name'] )
 
-            return ''
+            return retval.getvalue()
 
 class SetCommand(ExternalatorCommand):
     """ set the svn externals of bundle(s) """
@@ -1355,13 +1297,8 @@ def parse_options(parser, args=None):
         parser = command
 
     # add global options
+    # XXX this should probably live with the commands
     parser.add_option("-v", "--verbose", action="count", dest="verbose")
-    parser.add_option("-s", "--strict", 
-                      action="store_true", 
-                      dest="strict", 
-                      default=True)
-    parser.add_option("-n", "--nostrict", action="store_false", 
-                      dest="strict")
     parser.add_option("-m", "--message", dest="message", 
                       help="message to use for svn commits")
     parser.add_option("--readme", action="store_true", dest="readme")
